Boss Development Templates and Utilities
========================================

The Boss project provides 'Baseline Open Source Software' templates and
development tools.  It has similarities to PasteScript with regards to
templating, but far easier to extend.  Though Boss is written in Python, it is
can work with templates written for any language.

Boss is very beta... any feedback is welcome and appreciated.

**Features**

 * Supports multiple local, and remote (git) template sources
 * Templates can easily be created and customized to the developers needs
 * Support for remote files within templates (i.e. github/gitignore files)

**More Information**

 * RTFD: http://boss.readthedocs.org/en/latest/
 * CODE: https://github.com/datafolklabs/boss/
 * PYPI: http://pypi.python.org/pypi/boss
 *   CI: http://travis-ci.org/#!/datafolklabs/boss

**Official Templates**

 * http://github.com/datafolklabs/boss-templates


License
-------

The Boss project is Open Source and is distributed under the BSD License
(three clause).  Please see the LICENSE file included with this software.

